Example User Functions and Calling Scripts
==========================================

Here we give example generation, simulation, and allocation functions for
libEnsemble, as well as example calling scripts.

.. toctree::
   :maxdepth: 2
   :caption: libEnsemble Example Functions:

   gen_funcs
   sim_funcs
   alloc_funcs
   calling_scripts
